@@ -1,19 +1,19 @@
-"""
-Copyright (c) 2021, VRAI Labs and/or its affiliates. All rights reserved.
-
-This software is licensed under the Apache License, Version 2.0 (the
-"License") as published by the Apache Software Foundation.
-
-You may not use this file except in compliance with the License. You may
-obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-License for the specific language governing permissions and limitations
-under the License.
-"""
+# Copyright (c) 2021, VRAI Labs and/or its affiliates. All rights reserved.
+#
+# This software is licensed under the Apache License, Version 2.0 (the
+# "License") as published by the Apache Software Foundation.
+#
+# You may not use this file except in compliance with the License. You may
+# obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
 import json
+from math import ceil
+from time import time
 
 from supertokens_python.framework.response import BaseResponse
 
@@ -32,18 +32,17 @@ class DjangoResponse(BaseResponse):
             key,
             value,
             max_age,
-            expires,
+            ceil((expires - int(time() * 1000)) / 1000),
             path,
             domain,
             secure,
-            httponly,
-            samesite)
+            httponly)
+        self.response.cookies[key]['samesite'] = samesite
 
     def set_status_code(self, status_code):
         self.response.status_code = status_code
 
     def set_header(self, key, value):
-        # check if it is working with httpresponse
         self.response[key] = value
 
     def get_header(self, key):
